@@ -73,6 +73,8 @@ def with_import(module_name=None, function_name=None):
                     f'Unable to load {function_name} from {module_name}.py. '
                     f'Is {function_name} defined?'
                 )
+            except AssertionError as err:
+                pass
             except Exception as ex:
                 pytest.fail(
                     f'{type(ex).__name__}: {ex}\n'
